Module base

Module base 

Shared parser base types used by both Node and (legacy) AST.

These types are part of the “thin pipeline” surface area and should remain available even if the legacy fat AST is disabled.

Structs

NodeIndex
Index into an arena. Used instead of pointers/references for serialization-friendly graphs.
NodeList
A list of node indices, representing children or a node array.
TextRange
A text range with start and end positions. All positions are character indices (not byte indices).