Module flags

Module flags 

Node flags and modifier flags for AST nodes.

Modules

modifier_flags
Modifier flags for declarations. Matches TypeScript’s ModifierFlags enum exactly.
node_flags
Node flags indicating various properties of AST nodes. Matches TypeScript’s NodeFlags enum exactly. NOTE: wasm_bindgen doesn’t support bit-shift expressions, so these are stored as a u32 bitfield in NodeBase. Use the constants below for flag operations.
transform_flags
Transform flags indicate which transformations are needed for emit. Matches TypeScript’s TransformFlags enum.