NodeView

Struct NodeView 

pub struct NodeView<'a> {
    pub node: &'a Node,
    pub arena: &'a NodeArena,
    pub index: NodeIndex,
}
A view into a node that provides convenient access to both the Node header and its type-specific data. This avoids the need to pass the arena around when working with node data.

Fields

node: &'a Nodearena: &'a NodeArenaindex: NodeIndex

Implementations

Source

impl<'a> NodeView<'a>

pub fn new(arena: &'a NodeArena, index: NodeIndex) -> Option<Self>

Create a new NodeView.

pub const fn kind(&self) -> u16

Get the SyntaxKind.

pub const fn pos(&self) -> u32

Get the start position.

pub const fn end(&self) -> u32

Get the end position.

pub const fn flags(&self) -> u16

Get the flags.

pub const fn has_data(&self) -> bool

Check if this node has associated data.

pub fn extended(&self) -> Option<&'a ExtendedNodeInfo>

Get extended node info (parent, id, modifier/transform flags).

pub fn parent(&self) -> NodeIndex

Get parent node index.

pub fn id(&self) -> u32

Get node id.

pub fn child(&self, index: NodeIndex) -> Option<Self>

Get a child node as a NodeView.

pub fn as_identifier(&self) -> Option<&'a IdentifierData>

Get identifier data (for Identifier, PrivateIdentifier nodes).

pub fn as_literal(&self) -> Option<&'a LiteralData>

Get literal data (for StringLiteral, NumericLiteral, etc.).

pub fn as_binary_expr(&self) -> Option<&'a BinaryExprData>

Get binary expression data

pub fn as_call_expr(&self) -> Option<&'a CallExprData>

Get call expression data

pub fn as_function(&self) -> Option<&'a FunctionData>

Get function data

pub fn as_class(&self) -> Option<&'a ClassData>

Get class data

pub fn as_block(&self) -> Option<&'a BlockData>

Get block data

pub fn as_source_file(&self) -> Option<&'a SourceFileData>

Get source file data