pub fn look_ahead_is_const_enum(
scanner: &mut ScannerState,
current_token: SyntaxKind,
) -> boolExpand description
Look ahead to check if we have const enum.
pub fn look_ahead_is_const_enum(
scanner: &mut ScannerState,
current_token: SyntaxKind,
) -> boolLook ahead to check if we have const enum.