Module transform_utils

Module transform_utils 

Transform utilities for syntax analysis.

Common functions used by ES5 transformations.

Functions

contains_arguments_reference
Check if a node contains a reference to arguments.
contains_this_reference
Check if an AST node contains a reference to this or super.
is_private_identifier
Check if a node is a private identifier (#field)