contains_arguments_reference

Function contains_arguments_reference 

pub fn contains_arguments_reference(
    arena: &NodeArena,
    node_idx: NodeIndex,
) -> bool
Check if a node contains a reference to arguments.

This is used to determine if an arrow function needs to capture the parent’s arguments object for ES5 downleveling.

Important: Regular functions have their own arguments, so we don’t recurse into them. Only arrow functions inherit the parent’s arguments.