pub struct NodeInfo {
pub kind: u16,
pub flags: u32,
pub modifier_flags: u32,
pub pos: u32,
pub end: u32,
pub parent: NodeIndex,
pub id: u32,
}Expand description
Common node information that both arena types can provide. This struct contains the essential fields needed by most consumers.
Fields
kind: u16flags: u32modifier_flags: u32pos: u32end: u32parent: NodeIndexid: u32Implementations